<?php
/*
Plugin Name: SS Downloads
Plugin URI: http://www.strangerstudios.com/wordpress-plugins/ss-downloads/
Description: Email capture for content.
Version: 1.3.2
Author: Jason Coleman
Author URI: http://www.strangerstudios.com

Updates 1.3.1 to 1.3.2
- Fixed mimetype class conflict.

Updates 1.3 to 1.3.1
- Fixed the GETFILE_REDIRECT use in getfile.php

Updates 1.2.2 to 1.3
- Added cURL support and option
- Added ability to change the shortcode
- New "Email Sent" template
- Added "reset" service
- Added documentation on customizing setup.php

Updates 1.2.1 to 1.2.2
- Fixed definitions in setup.php to work with more hosts

Updates 1.2 to 1.2.1
- Bug fixes in addemail.php and emailform.php

Updates 1.01 to 1.2
- Setting to deliver file by email instead of showing a link
- Setting to require user sign up instead of an email address

*/

//version
add_option("ssd_db_version", "1.0");

//an include with some defines and functions
require_once("includes/setup.php");

//setup the DB
require_once(ABSPATH . '/wp-admin/upgrade-functions.php');

global $wpdb;
$wpdb->hide_errors();
$wpdb->justemails = $table_prefix . 'justemails';
$wpdb->ss_downloads = $table_prefix . 'ss_downloads';
$installed = $wpdb->get_results("SELECT id FROM $wpdb->ss_downloads");

if (mysql_errno() == 1146) 
{
	$sql = "CREATE TABLE " . $wpdb->ss_downloads . " (
			  `id` int(11) NOT NULL auto_increment,
			  `email` varchar(128) NOT NULL,
			  `file` varchar(255) NOT NULL,
			  `ip` varchar(16) NOT NULL,
			  `referrer` varchar(255) NOT NULL,
			  `timestamp` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
			  PRIMARY KEY  (`id`),
			  KEY `email` (`email`),
			  KEY `file` (`file`)
			)";
	$wpdb->query($sql);
	
	$sql = "CREATE TABLE " . $wpdb->justemails . " (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			email VARCHAR(128) NOT NULL,
			timestamp TIMESTAMP NOT NULL,
			UNIQUE KEY id (id), UNIQUE KEY `email` (`email`)
			);";	
	$wpdb->query($sql);
}

//shortcode function
function ssd_shortcode_handler($atts, $content=null, $code="") {
	global $current_user, $post;
	
	// $atts    ::= array of attributes
	// $content ::= text within enclosing form of shortcode element
	// $code    ::= the shortcode found, when == callback name
	// examples: [download title="title" file="/wp-content/uploads/filename.pdf"]
		
	extract(shortcode_atts(array(
		'title' => NULL,
		'file' => NULL,		
	), $atts));
	
	//no filename, just remove the shortcode
	if(!$file)
		return "[missing filename in your download code]";
		
	//no title, set it equal to the filename
	if(!$title)
		$title = basename($file);
	
	//settings
	$require = ssd_getOption("require");
	$delivery = ssd_getOption("delivery");
	$templatemethod = ssd_getOption("templatemethod");
	
	if(($require == "email" && $_SESSION['ssd_email_validates']) || ($require == "user" && $current_user->ID))
	{		
		if($delivery == "link")
		{		
			//show download box
			$tpath = str_replace('"', '\"', SSD_DOWNLOAD_URL . "?file=" . urlencode(ssd_swapChars($file)) . "&title=" . urlencode($title));
			if($templatemethod == "cURL")
			{
				$curl_handle=curl_init();
				curl_setopt($curl_handle, CURLOPT_URL, $tpath);
				curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, true);
				$r = curl_exec($curl_handle);
				curl_close($curl_handle);
			}
			else
				$r = file_get_contents($tpath);
		}
		else
		{
			//email_link and email_attachment			
			if($require == "email")
				$theemail = $_SESSION['ssd_email'];
			else
				$theemail = $current_user->user_email;
			
			$tpath = str_replace('"', '\"', SSD_EMAILSENT_URL . "?email=" . urlencode($theemail) . "&file=" . urlencode(ssd_swapChars($file)) . "&title=" . urlencode($title) . "&postid=" . $post->ID . "&require=" . $require . "&delivery=" . $delivery);
			
			if($templatemethod == "cURL")
			{
				$curl_handle=curl_init();
				curl_setopt($curl_handle, CURLOPT_URL, $tpath);
				curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, true);
				$r = curl_exec($curl_handle);
				curl_close($curl_handle);
			}
			else
				$r = file_get_contents($tpath);
		}
	}
	else
	{		
		if($_SESSION['ssd_email_failed'])
		{
			unset($_SESSION['ssd_email_failed']);
			$ssdmsg = 1;
		}
	
		//show register or email form		
		if($require == "email")
		{
			$tpath = str_replace('"', '\"', SSD_EMAIL_FORM_URL . "?file=" . urlencode(ssd_swapChars($file)) . "&title=" . urlencode($title) . "&postid=" . $post->ID . "&ssdmsg=" . $ssdmsg);
			if($templatemethod == "cURL")
			{
				$curl_handle=curl_init();
				curl_setopt($curl_handle, CURLOPT_URL, $tpath);
				curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, true);
				$r = curl_exec($curl_handle);
				curl_close($curl_handle);
			}
			else
				$r = file_get_contents($tpath);
		}
		else
		{			
			$tpath = str_replace('"', '\"', SSD_REGISTER_URL . "?login_url=" . urlencode(wp_login_url()) . "&redirect_to=" . urlencode(get_permalink($post->ID)));
			if($templatemethod == "cURL")
			{
				$curl_handle=curl_init();
				curl_setopt($curl_handle, CURLOPT_URL, $tpath);
				curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, true);
				$r = curl_exec($curl_handle);
				curl_close($curl_handle);
			}
			else
				$r = file_get_contents($tpath);
		}
	}
	
	return $r;
}

$ssdshortcode = ssd_getOption("shortcode");
if(!$ssdshortcode)
{
	$ssdshortcode = "download";
	ssd_setOption("ssdshortcode", $ssdshortcode);
}
add_shortcode($ssdshortcode, 'ssd_shortcode_handler');

//add stylesheet on front end
function ssd_print_styles() {
	$myStyleUrl = WP_PLUGIN_URL . '/ss-downloads/css/ss-downloads.css';
	$myStyleFile = WP_PLUGIN_DIR . '/ss-downloads/css/ss-downloads.css';
	if ( file_exists($myStyleFile) ) {
		wp_register_style('ss-downloads', $myStyleUrl);
		wp_enqueue_style( 'ss-downloads');
	}
}
add_action('wp_print_styles', 'ssd_print_styles');

//setup and function for mailing list tab
function ssd_add_pages() 
{	
	add_management_page('SS Downloads', 'SS Downloads', 8, 'ssdownloads', 'ssd_ss_downloads');
}

function ssd_ss_downloads()
{
	global $wpdb;		
	
	$sql = "SELECT je.email, UNIX_TIMESTAMP(je.timestamp) as timestamp FROM $wpdb->justemails je ";		
	$collected_emails = $wpdb->get_col($sql);
		
	?>
	<div class="wrap">				
		
		<h2>Collected Email Addresses</h2>				
		<textarea style="width: 500px; height: 100px;"><?=implode(", ", $collected_emails)?></textarea>		
        
        <h2>
        	File Downloads
            <small>(<a target="_blank" href="<?=get_bloginfo("url")?>/wp-content/plugins/ss-downloads/services/exportdownloads.php">Download Full Report</a>)</small>
        </h2>
        <table class="widefat page fixed" cellspacing="0">
        	<thead>
            	<tr>
                	<th class="manage-column" scope="col" width="70%">File</th>
                    <th class="manage-column" scope="col"># Downloads</th>
                    <th class="manage-column" scope="col">Last Download</th>
                </tr>
            </thead>
            <tbody>
            	<?php
					$sql = "SELECT file as filename, COUNT(id) as num, MAX(UNIX_TIMESTAMP(timestamp)) as timestamp FROM $wpdb->ss_downloads GROUP BY file ORDER BY timestamp DESC";
					$files = $wpdb->get_results($sql);
					
					if(count($files))
					{
						foreach($files as $file)
						{
						?>
						<tr>
							<td><a target="_blank" href="<?=$file->filename?>"><?=$file->filename?></a></td>
							<td><?=$file->num?></td>
							<td><?=date("n/d/Y g:i A e", $file->timestamp)?></td>
						</tr>
						<?php
						}
					}
					else
					{
					?>
                    <tr>
                    	<td colspan="3"><p>No downloads yet.</p></td>
                    </tr>
                    <?php
					}
				?>
            </tbody>
        </table>
        
        <h2>Settings</h2>
        <form action="" method="post" enctype="multipart/form-data">   
        <?php
			//get/set settings
			if($_REQUEST['savesettings'])
			{
				ssd_setOption("require");
				ssd_setOption("delivery");
				ssd_setOption("templatemethod");
				ssd_setOption("ssdshortcode");
			}

			$require = ssd_getOption("require");
			$delivery = ssd_getOption("delivery");
			$templatemethod = ssd_getOption("templatemethod");
			$ssdshortcode = ssd_getOption("ssdshortcode");
			
			//default settings
			if(!$require)
			{
				$require = "email";
				ssd_setOption("require", $require);
			}	
			if(!$delivery)
			{
				$delivery = "link";
				ssd_setOption("delivery", $delivery);
			}	
			if(!$templatemethod)
			{
				$templatemethod = "file_get_contents";
				ssd_setOption("file_get_contents", $templatemethod);
			}	
			if(!$ssdshortcode)
			{
				$ssdshortcode = "download";
				ssd_setOption("ssdshortcode", $ssdshortcode);
			}	
		?>
            <table class="form-table">
            <tbody>                
                <tr>
                    <th scope="row" valign="top" colspan="2">
                        <label for="require">Required For Downloads:</label><br />
                        <select name="require">
                        	<option value="email" <?php if($require == "email") { ?>selected="selected"<?php } ?>>Properly Formatted Email Address</option>
                            <option value="user" <?php if($require == "user") { ?>selected="selected"<?php } ?>>User Signup</option>
                        </select>                       
                    </th>
                </tr>                 
                <tr>
                    <th scope="row" valign="top" colspan="2">
                        <label for="delivery">File Delivery Method:</label><br />
                        <select name="delivery">
                        	<option value="link" <?php if($delivery == "link") { ?>selected="selected"<?php } ?>>Show Link to File</option>
                            <option value="email_attachment" <?php if($delivery == "email_attachment") { ?>selected="selected"<?php } ?>>Send File as Email Attachment</option>
                            <option value="email_link" <?php if($delivery == "email_link") { ?>selected="selected"<?php } ?>>Send Link to File by Email</option>
                        </select>                        
                    </th>
                </tr>
                <tr>
                    <th scope="row" valign="top" colspan="2">
                        <label for="templatemethod">Template Method:</label><br />
                        <select name="templatemethod">
                        	<option value="file_get_contents" <?php if($templatemethod == "file_get_contents") { ?>selected="selected"<?php } ?>>file_get_contents()</option>                            <option value="cURL" <?php if($templatemethod == "cURL") { ?>selected="selected"<?php } ?>>cURL</option>
                        </select>     
                        <br /><small>If you don't see the download form and/or see errors, changing this might help.</small>                   
                    </th>
                </tr>
                <tr>
                    <th scope="row" valign="top" colspan="2">
                        <label for="ssdshortcode">Shortcode:</label><br />
                        <input type="text" name="ssdshortcode" value="<?=$ssdshortcode?>" />    
                        <br /><small>Can change this to resolve plugin conflicts.</small>
                        
                       	<p>
                        	With your current settings, your shortcode to embed a download form would be something like:<br />
                            <strong>[<?=$ssdshortcode?> file="filename.txt" title="title"]</strong>
                        </p>
                    </th>
                </tr>
            </tbody>
         	</table>
            
            <p class="submit">            
                <input name="savesettings" type="submit" value="Save Settings" /> 		                			
            </p> 
         </form>
	</div>
	<?php
}

add_action('admin_menu', 'ssd_add_pages');
?>
